# Client library for Yamcs.
[![Website](https://img.shields.io/website/http/shields.io.svg?label=docs)](https://www.yamcs.org/yamcs-python/yamcs-client)
[![Build Status](https://travis-ci.org/yamcs/yamcs-python.svg?branch=master)](https://travis-ci.org/yamcs/yamcs-python)
[![PyPI](https://img.shields.io/pypi/v/yamcs-client.svg)](https://pypi.python.org/pypi/yamcs-client)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/yamcs-client.svg)](https://pypi.python.org/pypi/yamcs-client/)

## Documentation
https://www.yamcs.org/yamcs-python/yamcs-client

## Development Setup

Install build dependencies (you may want to do this in a virtualenv):

    pip install -r requirements.txt


Install `yamcs-client` from the source base:

    python setup.py develop

Changes to any source file have immediate impact.


## License

LGPL-3.0. See [LICENSE](https://github.com/yamcs/yamcs-python/blob/master/LICENSE)
